#ifndef NT2_INCLUDE_FUNCTIONS_ACSCH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACSCH_HPP_INCLUDED

#include <nt2/hyperbolic/include/functions/acsch.hpp>

#endif
